@@ -6,10 +6,11 @@ from airflow.utils.timezone import datetime
 
 from astronomer.providers.http.sensors.http import HttpSensorAsync
 
-HTTP_CONN_ID = os.environ.get("ASTRO_HTTP_CONN_ID", "http_default")
+HTTP_CONN_ID = os.getenv("ASTRO_HTTP_CONN_ID", "http_default")
+EXECUTION_TIMEOUT = int(os.getenv("EXECUTION_TIMEOUT", 6))
 
 default_args = {
-    "execution_timeout": timedelta(minutes=30),
+    "execution_timeout": timedelta(hours=EXECUTION_TIMEOUT),
 }
 
 
@@ -31,6 +32,6 @@ with DAG(
         # response_check=lambda response: "httpbin" in response.text,
         poke_interval=5,
     )
-    # [START howto_operator_file_sensor_async]
+    # [END howto_operator_file_sensor_async]
 
     async_http_sensor
